@@ -9,10 +9,6 @@ class GenerationTrainArguments:
         default="kogpt2",
         metadata={"help": "pretrained model name"}
     )
-    pretrained_model_cache_dir: str = field(
-        default="model",
-        metadata={"help": "pretrained model name"}
-    )
     downstream_task_name: str = field(
         default="sentence-generation",
         metadata={"help": "The name of the downstream data."}
@@ -125,14 +121,15 @@ class GenerationDeployArguments:
         default=None,
         metadata={"help": "The name of the pretrained model"}
     )
+    pretrained_model_cache_dir: str = field(
+        default=None,
+        metadata={"help": "The pretrained model checkpoint path."}
+    )
     downstream_model_checkpoint_path: str = field(
         default=None,
         metadata={"help": "The output model checkpoint path."}
     )
-    max_seq_length: int = field(
-        default=64,
-        metadata={
-            "help": "The maximum total input sequence length after tokenization. Sequences longer "
-                    "than this will be truncated, sequences shorter will be padded."
-        }
+    force_download: bool = field(
+        default=False,
+        metadata={"help": "force to download downstream data and pretrained models."}
     )
