@@ -3,6 +3,7 @@ from transformers.optimization import AdamW
 from pytorch_lightning import LightningModule
 from ratsnlp.nlpbook.generation.arguments import GenerationTrainArguments
 from torch.optim.lr_scheduler import ExponentialLR, CosineAnnealingWarmRestarts
+from transformers.modeling_outputs import ModelOutput
 
 
 class GenerationTask(LightningModule):
@@ -31,19 +32,12 @@ class GenerationTask(LightningModule):
             'scheduler': scheduler,
         }
 
-    def forward(self, **kwargs):
-        return self.model(**kwargs)
-
-    def step(self, inputs, mode="train"):
-        loss, logits, _ = self.model(**inputs)
-        self.log(f"{mode}_loss", loss, prog_bar=True, logger=True, on_step=True, on_epoch=True)
-        return loss
-
     def training_step(self, inputs, batch_idx):
-        return self.step(inputs, mode="train")
+        loss, _, _ = self.model(**inputs)
+        self.log("train_loss", loss, prog_bar=True, logger=True, on_step=True, on_epoch=True)
+        return {"loss": loss}
 
     def validation_step(self, inputs, batch_idx):
-        return self.step(inputs, mode="val")
-
-    def test_step(self, inputs, batch_idx):
-        return self.step(inputs, mode="test")
+        loss, _, _ = self.model(**inputs)
+        self.log("val_loss", loss, prog_bar=True, logger=True, on_step=True, on_epoch=True)
+        return {"loss": loss}
